@@ -189,6 +189,7 @@ int color_gmstrd;
 /*
  * currenttime.c
  */
+TimeType global_time_offset;
 char is_vcd; /* from currenttime.c 56 */
 char partial_vcd; /* from currenttime.c 57 */
 char use_maxtime_display; /* from currenttime.c 58 */
@@ -452,6 +453,7 @@ int dict_32_offset_lxt_c_1; /* from lxt.c 189 */
 unsigned int dict_width_lxt_c_1; /* from lxt.c 190 */
 char **dict_string_mem_array_lxt_c_1; /* from lxt.c 191 */
 int exclude_offset_lxt_c_1; /* from lxt.c 192 */
+int lxt_timezero_offset;
 char *lt_buf_lxt_c_1; /* from lxt.c 193 */
 int lt_len_lxt_c_1; /* from lxt.c 194 */
 int fd_lxt_c_1; /* from lxt.c 195 */
