@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2008 Tony Bybell.
+ * Copyright (c) 2003-2012 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -663,11 +663,24 @@ if((lt)&&(lt->numfacs))
 			lt->sorted_facs[i]->facnum = i;
 			}
 
-		lt->facname_offset=lt->position;
+                if(!lt->timezero)
+                        {
+                        lxt2_wr_emit_u32(lt, lt->numfacs);       /* uncompressed */
+                        }
+                        else
+                        {
+                        lxt2_wr_emit_u32(lt, 0);                 /* uncompressed, flag to insert extra parameters */
+                        lxt2_wr_emit_u32(lt, 8);                 /* uncompressed 8 counts timezero and on */
+                        lxt2_wr_emit_u32(lt, lt->numfacs);       /* uncompressed */
+                        lxt2_wr_emit_u64(lt, (lt->timezero >> 32) & 0xffffffffL, lt->timezero & 0xffffffffL); /* uncompressed */
+                        }
+
 
-		lxt2_wr_emit_u32(lt, lt->numfacs);	/* uncompressed */
 		lxt2_wr_emit_u32(lt, lt->numfacbytes);	/* uncompressed */
 		lxt2_wr_emit_u32(lt, lt->longestname);	/* uncompressed */
+
+		lt->facname_offset=lt->position;
+
 		lxt2_wr_emit_u32(lt, 0); 		/* uncompressed : placeholder for zfacnamesize     */
 		lxt2_wr_emit_u32(lt, 0);		/* uncompressed : placeholder for zfacname_predec_size */
 		lxt2_wr_emit_u32(lt, 0); 		/* uncompressed : placeholder for zfacgeometrysize */
@@ -720,7 +733,7 @@ if((lt)&&(lt->numfacs))
 		lt->break_header_size = lt->position;			/* in case we need to emit multiple lxt2s with same header */
 		lt->zfacgeometry_size = lt->position - lt->facgeometry_offset;
 
-		fseeko(lt->handle, lt->facname_offset + 12, SEEK_SET);
+		fseeko(lt->handle, lt->facname_offset, SEEK_SET);
 		lxt2_wr_emit_u32(lt, lt->zfacname_size);		/* backpatch sizes... */
 		lxt2_wr_emit_u32(lt, lt->zfacname_predec_size);
 		lxt2_wr_emit_u32(lt, lt->zfacgeometry_size);
@@ -1144,7 +1157,7 @@ unsigned int total_chgs;
 unsigned int partial_length;
 
 total_chgs = 0;
-partial_length = 0;
+/* partial_length = 0; */ /* scan-build : never read */
 
 iter_hi = iter + partial_iter;
 if(iter_hi > lt->numfacs) iter_hi = lt->numfacs;
@@ -1491,8 +1504,6 @@ if(lt)
 
 	if( (!lt->timepos) && (!lt->timegranule) && ((!lt->numblock)||(!lt->no_checkpoint)) )
 	        {
-	        struct lxt2_wr_symbol *s = lt->symchain;
-
 		/* fprintf(stderr, "initial value burst timepos==0, timegranule==0\n"); */
 		if(lt->blackout)
 			{
@@ -1501,7 +1512,7 @@ if(lt)
 			}
 		else
 			{
-			s = lt->symchain;
+			struct lxt2_wr_symbol *s = lt->symchain;
 		        while(s)
 		                {
 		                if((!(s->flags&LXT2_WR_SYM_F_ALIAS))&&(s->rows<2))
@@ -2180,3 +2191,15 @@ if(lt)
 	}
 }
 
+
+/*
+ * time zero offset      
+ */
+void lxt2_wr_set_timezero(struct lxt2_wr_trace *lt, lxtstime_t timeval)               
+{                        
+if(lt)
+        {                
+        lt->timezero = timeval;
+        }                 
+}
+
